import React, { useState, useCallback, useEffect } from 'react';
import ReactDOM from 'react-dom';
import { useDataMap } from './useDataMap';
import { useDataViews } from './useDataViews';
import { Marks } from './Marks';
import { scaleLinear, extent, scaleSqrt, max, histogram as bin, sum, nest } from 'd3';

const width = 960;
const height = 500;

const App = () => {
  const mapData = useDataMap();
  const viewData = useDataViews();
  
  if (!mapData || !viewData) {
    return <pre>Loading...</pre>;
  }
  
  
  const lng = d => d.Lng;
  const lat = d => d.Lat;
  const country = d => d.Countries;
  const views = d => d.nplay_video;
  const course = d => d.Course;
  const school = d => d.School;
  const age = d => d.age;
  const gender = d => d.gender;

  
  
  const sizeValue = d => d.views;
  const maxRadius = 7
  const sizeScale = scaleSqrt()
  .domain([0, max(viewData, sizeValue)])
  .range([0, maxRadius] );

const viewsPerCountry = [
  {country : viewData}]



  return (
		<svg width={width} height={height}>
      <Marks 
        mapData={mapData}
        viewData={viewData}
        lng={lng} 
        lat={lat} 
        views={views}
        country={country}
        course={course}
        school={school}
        age={age}
        gender={gender}
        sizeScale={sizeScale}
        sizeValue={sizeValue}
        viewsPerCountry={viewsPerCountry}
  

        />
    </svg>
  );
};
const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);
